mur_seasons_arc_pa: Simulated seasonal arc presence absence data for Murphy Cr

mur_seasons_arc_paR Documentation

Simulated seasonal arc presence absence data for Murphy Cr

Description

A data frame with one hundred multivariate Bernoulli simulated outcomes representing spring, summer and fall.

Usage

data("mur_seasons_arc_pa")

Format

A data frame with 300 observations on the following 28 variables.

‘⁠IN_N -> M1984⁠’

a numeric vector

‘⁠M1984 -> M1909⁠’

a numeric vector

‘⁠M1909 -> M1799⁠’

a numeric vector

‘⁠IN_S -> M1993⁠’

a numeric vector

‘⁠M1993 -> M1951⁠’

a numeric vector

‘⁠M1951 -> M1909⁠’

a numeric vector

‘⁠M1799 -> M1719⁠’

a numeric vector

‘⁠M1719 -> M1653⁠’

a numeric vector

‘⁠M1653 -> M1572⁠’

a numeric vector

‘⁠M1572 -> M1452⁠’

a numeric vector

‘⁠M1452 -> M1377⁠’

a numeric vector

‘⁠M1377 -> M1254⁠’

a numeric vector

‘⁠M1254 -> M1166⁠’

a numeric vector

‘⁠M1166 -> M1121⁠’

a numeric vector

‘⁠M1121 -> M1036⁠’

a numeric vector

‘⁠M1036 -> M918⁠’

a numeric vector

‘⁠M918 -> M823⁠’

a numeric vector

‘⁠M823 -> M759⁠’

a numeric vector

‘⁠M759 -> M716⁠’

a numeric vector

‘⁠M716 -> M624⁠’

a numeric vector

‘⁠M624 -> M523⁠’

a numeric vector

‘⁠M523 -> M454⁠’

a numeric vector

‘⁠M454 -> M380⁠’

a numeric vector

‘⁠M380 -> M233⁠’

a numeric vector

‘⁠M233 -> M153⁠’

a numeric vector

‘⁠M153 -> M91⁠’

a numeric vector

‘⁠M91 -> OUT⁠’

a numeric vector

Season

A categorical variable with three levels: "spring" (6/3/2019 - 7/13/2019), "summer" (7/13/2019 - 8/23/2019) and "fall" (8/23/2019 - 10/2/2019)


streamDAG documentation built on April 4, 2025, 12:28 a.m.